# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`simp_openldap`](#simp_openldap): Provides the base configuration necessary for an OpenLDAP client or server.
* [`simp_openldap::client`](#simp_openldapclient): Install the openldap-clients package and configure global options
* [`simp_openldap::server`](#simp_openldapserver): Set up an OpenLDAP server
* [`simp_openldap::slapo::lastbind`](#simp_openldapslapolastbind): Configures lastbind and set up a dynamic include that defines lastbind.
* [`simp_openldap::slapo::ppolicy`](#simp_openldapslapoppolicy): Configure the password policy for a site
* [`simp_openldap::slapo::syncprov`](#simp_openldapslaposyncprov): Allow other LDAP servers to synchronize with this one

#### Private Classes

* `simp_openldap::server::conf`: Configures the brunt of the ``/etc/openldap`` configuration files
* `simp_openldap::server::conf::default_ldif`: Allows for the modification of the default LDIF entries in
* `simp_openldap::server::fix_bad_upgrade`: Workaround upgrade issues
* `simp_openldap::server::install`: Install the required packages
* `simp_openldap::server::service`: Manage the OpenLDAP service

### Defined types

* [`simp_openldap::server::access`](#simp_openldapserveraccess): Manage access control entries in ``slapd.access``
* [`simp_openldap::server::dynamic_include`](#simp_openldapserverdynamic_include): Add a dynamically included file into the LDAP system.
* [`simp_openldap::server::limits`](#simp_openldapserverlimits): Manage ``limits`` sections under the **main** database
* [`simp_openldap::server::syncrepl`](#simp_openldapserversyncrepl): Configures the syncrepl functionality of OpenLDAP which allows

### Data types

* [`Simp_Openldap::LogLevel`](#simp_openldaploglevel): OpenLDAP Log Levels
* [`Simp_Openldap::SlapdConf::Disallow`](#simp_openldapslapdconfdisallow): OpenLDAP slapd.conf disallow

## Classes

### <a name="simp_openldap"></a>`simp_openldap`

Further configuration can be made via the simp_openldap::client and
simp_openldap::server classes.

#### Parameters

The following parameters are available in the `simp_openldap` class:

* [`ldap_uri`](#ldap_uri)
* [`base_dn`](#base_dn)
* [`bind_dn`](#bind_dn)
* [`ldap_master`](#ldap_master)
* [`is_server`](#is_server)
* [`pki`](#pki)
* [`app_pki_external_source`](#app_pki_external_source)
* [`app_pki_dir`](#app_pki_dir)
* [`app_pki_key`](#app_pki_key)
* [`app_pki_cert`](#app_pki_cert)
* [`app_pki_ca_dir`](#app_pki_ca_dir)
* [`app_pki_crl`](#app_pki_crl)

##### <a name="ldap_uri"></a>`ldap_uri`

Data type: `Array[Simplib::URI]`

It is recommended that you make the master the last entry in this array

Default value: `simplib::lookup('simp_options::ldap::uri', { 'default_value' => undef })`

##### <a name="base_dn"></a>`base_dn`

Data type: `String`

The base DN of the LDAP entries

Default value: `simplib::lookup('simp_options::ldap::base_dn', { 'default_value' => simplib::ldap::domain_to_dn() })`

##### <a name="bind_dn"></a>`bind_dn`

Data type: `String`

The user that should be used to bind to the LDAP server

Default value: `simplib::lookup('simp_options::ldap::bind_dn', { 'default_value' => sprintf('cn=hostAuth,ou=Hosts,%s', simplib::ldap::domain_to_dn()) })`

##### <a name="ldap_master"></a>`ldap_master`

Data type: `Simplib::URI`

The LDAP Master server

* Will default to the **last** entry in ``ldap_uri`` if not set
* Only applicable for LDAP server configuration when chain overlay is
  enabled

Default value: `simplib::lookup('simp_options::ldap::master', { 'default_value'  => $ldap_uri[-1] })`

##### <a name="is_server"></a>`is_server`

Data type: `Boolean`

Set this if you want to create an OpenLDAP server on your node

Default value: ``false``

##### <a name="pki"></a>`pki`

Data type: `Variant[Boolean, Enum['simp']]`

* If 'simp', include SIMP's pki module and use pki::copy to manage
  application certs in /etc/pki/simp_apps/openldap/x509
* If true, do *not* include SIMP's pki module, but still use pki::copy
  to manage certs in /etc/pki/simp_apps/openldap/x509
* If false, do not include SIMP's pki module and do not use pki::copy
  to manage certs.  You will need to appropriately assign a subset of:
  * app_pki_dir
  * app_pki_key
  * app_pki_cert
  * app_pki_ca
  * app_pki_ca_dir

Default value: `simplib::lookup('simp_options::pki', { 'default_value' => false })`

##### <a name="app_pki_external_source"></a>`app_pki_external_source`

Data type: `String`

* If pki = 'simp' or true, this is the directory from which certs will be
  copied, via pki::copy.  Defaults to /etc/pki/simp/x509.

* If pki = false, this variable has no effect.

Default value: `simplib::lookup('simp_options::pki::source', { 'default_value' => '/etc/pki/simp/x509' })`

##### <a name="app_pki_dir"></a>`app_pki_dir`

Data type: `Stdlib::Absolutepath`

This variable controls the basepath of $app_pki_key, $app_pki_cert,
$app_pki_ca, $app_pki_ca_dir, and $app_pki_crl.
It defaults to /etc/pki/simp_apps/openldap/x509.

Default value: `'/etc/pki/simp_apps/openldap/x509'`

##### <a name="app_pki_key"></a>`app_pki_key`

Data type: `Stdlib::AbsolutePath`

Path and name of the private SSL key file.

Default value: `"${app_pki_dir}/private/${facts['fqdn']}.pem"`

##### <a name="app_pki_cert"></a>`app_pki_cert`

Data type: `Stdlib::AbsolutePath`

Path and name of the public SSL certificate.

Default value: `"${app_pki_dir}/public/${facts['fqdn']}.pub"`

##### <a name="app_pki_ca_dir"></a>`app_pki_ca_dir`

Data type: `Stdlib::AbsolutePath`

Path to the CA.

Default value: `"${app_pki_dir}/cacerts"`

##### <a name="app_pki_crl"></a>`app_pki_crl`

Data type: `Optional[Stdlib::Absolutepath]`

Path to the CRL file.

Default value: ``undef``

### <a name="simp_openldapclient"></a>`simp_openldap::client`

for accessing the LDAP servers.

* **See also**
  * ldap.conf(5)
    * for details.

#### Parameters

The following parameters are available in the `simp_openldap::client` class:

* [`uri`](#uri)
* [`base_dn`](#base_dn)
* [`bind_dn`](#bind_dn)
* [`deref`](#deref)
* [`referrals`](#referrals)
* [`sizelimit`](#sizelimit)
* [`timelimit`](#timelimit)
* [`use_tls`](#use_tls)
* [`app_pki_key`](#app_pki_key)
* [`app_pki_cert`](#app_pki_cert)
* [`app_pki_ca_dir`](#app_pki_ca_dir)
* [`app_pki_crl`](#app_pki_crl)
* [`strip_128_bit_ciphers`](#strip_128_bit_ciphers)
* [`tls_cipher_suite`](#tls_cipher_suite)
* [`tls_crlcheck`](#tls_crlcheck)
* [`tls_reqcert`](#tls_reqcert)
* [`openldap_clients_ensure`](#openldap_clients_ensure)
* [`nss_pam_ldapd_ensure`](#nss_pam_ldapd_ensure)

##### <a name="uri"></a>`uri`

Data type: `Array[Simplib::URI]`

LDAP servers

Default value: `$simp_openldap::ldap_uri`

##### <a name="base_dn"></a>`base_dn`

Data type: `Optional[String]`

The base DN of the LDAP entries

Default value: `$simp_openldap::base_dn`

##### <a name="bind_dn"></a>`bind_dn`

Data type: `String[1]`

The user that should be used to bind to the LDAP server

Default value: `$simp_openldap::bind_dn`

##### <a name="deref"></a>`deref`

Data type: `Enum['never','searching','finding','always']`

How alias dereferencing is done when performing a search

Default value: `'never'`

##### <a name="referrals"></a>`referrals`

Data type: `Enum['on','off']`

Whether the client should automatically follow referrals returned by LDAP servers

Default value: `'on'`

##### <a name="sizelimit"></a>`sizelimit`

Data type: `Integer`

Size limit (number of entries) to use when performing searches

Default value: `0`

##### <a name="timelimit"></a>`timelimit`

Data type: `Integer`

Time limit (in seconds) to use when performing searches

Default value: `15`

##### <a name="use_tls"></a>`use_tls`

Data type: `Variant[Enum['simp'],Boolean]`

Use TLS when connecting to the ldap server. By default this will mirror
simp_options::pki, but needs to be distinct as the client and server
configurations could vary.

Default value: `$simp_openldap::pki`

##### <a name="app_pki_key"></a>`app_pki_key`

Data type: `Stdlib::Absolutepath`

Path and name of the private SSL key file

Default value: `$simp_openldap::app_pki_key`

##### <a name="app_pki_cert"></a>`app_pki_cert`

Data type: `Stdlib::Absolutepath`

Path and name of the public SSL certificate

Default value: `$simp_openldap::app_pki_cert`

##### <a name="app_pki_ca_dir"></a>`app_pki_ca_dir`

Data type: `Stdlib::Absolutepath`

Path to the CA.

Default value: `$simp_openldap::app_pki_ca_dir`

##### <a name="app_pki_crl"></a>`app_pki_crl`

Data type: `Optional[Stdlib::Absolutepath]`

Path to the CRL file.

Default value: `$simp_openldap::app_pki_crl`

##### <a name="strip_128_bit_ciphers"></a>`strip_128_bit_ciphers`

Data type: `Optional[Boolean]`

* **DEPRECATED**

Default value: ``undef``

##### <a name="tls_cipher_suite"></a>`tls_cipher_suite`

Data type: `Array[String[1]]`

The default ciphers to use for TLS

Default value: `simplib::lookup('simp_options::openssl::cipher_suite', { 'default_value' => ['DEFAULT','!MEDIUM'] })`

##### <a name="tls_crlcheck"></a>`tls_crlcheck`

Data type: `Enum['none','peer','all']`

Whether the Certificate Revocation List (CRL) of the CA should be used to
verify if the server certificates have not been revoked

Default value: `'none'`

##### <a name="tls_reqcert"></a>`tls_reqcert`

Data type: `Enum['never','allow','try','demand','hard']`

The checks to perform on server certificates in a TLS session

Default value: `'allow'`

##### <a name="openldap_clients_ensure"></a>`openldap_clients_ensure`

Data type: `String`

The ensure status of the openldap-clients package

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### <a name="nss_pam_ldapd_ensure"></a>`nss_pam_ldapd_ensure`

Data type: `String`

**DEPRECATED** The nss-pam-ldapd package is no longer installed

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

### <a name="simp_openldapserver"></a>`simp_openldap::server`

It installs the server if not already installed and bootstraps it if
necessary.

You can quickly reset the entire server by removing all files from
``/var/lib/ldap/db/*`` and then re-running puppet. Note that this will erase
the contents of your database, so you will want to use ``slapcat`` to save
any data that you may require later for restoration.

If you need to re-bootstrap, you also must remove the file
``/etc/openldap/puppet_bootstrapped.lock`` since this is in place as a
protective measure.

Please look at the ``simp_openldap::server::access`` stanzas below so that
you can understand how to modify the access controls via puppet.

The default access settings start at ``1000`` and go through ``3000`` except
for a default entry at ``100000`` that allows users to read everything and
then denies access. These are spread this far apart so that you can easily
override and/or circumvent them to your site specifications.

**NOTE:** To get the bootstrap to run again, you must remove the lock file at
``/etc/openldap/puppet_bootstrapped.lock`` *and* remove the database files in
``/var/lib/ldap/db/*``.

#### Parameters

The following parameters are available in the `simp_openldap::server` class:

* [`schema_sync`](#schema_sync)
* [`schema_source`](#schema_source)
* [`allow_sync`](#allow_sync)
* [`sync_dn`](#sync_dn)
* [`use_ppolicy`](#use_ppolicy)
* [`tcpwrappers`](#tcpwrappers)

##### <a name="schema_sync"></a>`schema_sync`

Data type: `Boolean`

Synchronize all schemas from ``$schema_source``

Default value: ``true``

##### <a name="schema_source"></a>`schema_source`

Data type: `String`

The location from which to download the schemas

Default value: `"puppet:///modules/${module_name}/etc/openldap/schema"`

##### <a name="allow_sync"></a>`allow_sync`

Data type: `Boolean`

Provide the ability for other hosts to use LDAP synchronization as clients
to this server

* Class variables will need to be set according to the
  ``simp_openldap::slapo::syncprov`` class requirements

Default value: ``true``

##### <a name="sync_dn"></a>`sync_dn`

Data type: `String`

The DN that is allowed to synchronize from the LDAP server

Default value: `simplib::lookup('simp_options::ldap::sync_dn', { 'default_value' => "cn=LDAPSync,ou=Hosts,${simp_openldap::base_dn}" })`

##### <a name="use_ppolicy"></a>`use_ppolicy`

Data type: `Boolean`

Include the default password policy overlay

Default value: ``true``

##### <a name="tcpwrappers"></a>`tcpwrappers`

Data type: `Boolean`

If true, enable tcpwrappers for slapd.

Default value: `simplib::lookup('simp_options::tcpwrappers', { 'default_value' => false })`

### <a name="simp_openldapslapolastbind"></a>`simp_openldap::slapo::lastbind`

Configures lastbind and set up a dynamic include that defines lastbind.

* **See also**
  * slapo-lastbind(5)
    * for details of the options.

#### Parameters

The following parameters are available in the `simp_openldap::slapo::lastbind` class:

* [`lastbind_precision`](#lastbind_precision)
* [`lastbind_ensure`](#lastbind_ensure)

##### <a name="lastbind_precision"></a>`lastbind_precision`

Data type: `Integer[0]`

Determines the amount of time, in seconds, after which to update the
authTimestamp entry.

Default value: `3600`

##### <a name="lastbind_ensure"></a>`lastbind_ensure`

Data type: `String`

The ensure status of packages to be managed

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

### <a name="simp_openldapslapoppolicy"></a>`simp_openldap::slapo::ppolicy`

This also includes the options for configuring the password checking plugin
that's included with SIMP.

* **See also**
  * slapo-ppolicy(5)

#### Parameters

The following parameters are available in the `simp_openldap::slapo::ppolicy` class:

* [`suffix`](#suffix)
* [`min_points`](#min_points)
* [`use_cracklib`](#use_cracklib)
* [`min_upper`](#min_upper)
* [`min_lower`](#min_lower)
* [`min_digit`](#min_digit)
* [`min_punct`](#min_punct)
* [`max_consecutive_per_class`](#max_consecutive_per_class)
* [`ppolicy_ensure`](#ppolicy_ensure)
* [`ppolicy_default`](#ppolicy_default)
* [`ppolicy_hash_cleartext`](#ppolicy_hash_cleartext)
* [`ppolicy_use_lockout`](#ppolicy_use_lockout)

##### <a name="suffix"></a>`suffix`

Data type: `Optional[String[1]]`

The Base DN of the LDAP domain to which you wish to connect.

Default value: `$simp_openldap::base_dn`

##### <a name="min_points"></a>`min_points`

Data type: `Integer[0]`

The minimum number of character classes that must be included in your
password for it to succeed.

Default value: `3`

##### <a name="use_cracklib"></a>`use_cracklib`

Data type: `Boolean`

If true, use cracklib when checking the password.

Default value: ``true``

##### <a name="min_upper"></a>`min_upper`

Data type: `Integer[0]`

The minimum number of upper case characters that must be present for the
password to be valid.

Default value: `0`

##### <a name="min_lower"></a>`min_lower`

Data type: `Integer[0]`

The minimum number of lower case characters that must be present for the
password to be valid.

Default value: `0`

##### <a name="min_digit"></a>`min_digit`

Data type: `Integer[0]`

The minimum number of digit characters that must be present for the
password to be valid.

Default value: `0`

##### <a name="min_punct"></a>`min_punct`

Data type: `Integer[0]`

The minimum number of punctuation characters that must be present for the
password to be valid.

Default value: `0`

##### <a name="max_consecutive_per_class"></a>`max_consecutive_per_class`

Data type: `Integer[0]`

The maximum number of characters from any character class that can exist in
a row.

Default value: `3`

##### <a name="ppolicy_ensure"></a>`ppolicy_ensure`

Data type: `String`

The ensure status of the simp-ppolicy-check-password
package

Default value: `simplib::lookup('simp_options::package_ensure', { 'default_value' => 'installed' })`

##### <a name="ppolicy_default"></a>`ppolicy_default`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ppolicy_hash_cleartext"></a>`ppolicy_hash_cleartext`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="ppolicy_use_lockout"></a>`ppolicy_use_lockout`

Data type: `Optional[String[1]]`



Default value: ``undef``

### <a name="simp_openldapslaposyncprov"></a>`simp_openldap::slapo::syncprov`

Allow other LDAP servers to synchronize with this one

* **See also**
  * slapo-syncprov(5)

#### Parameters

The following parameters are available in the `simp_openldap::slapo::syncprov` class:

* [`checkpoint`](#checkpoint)
* [`sessionlog`](#sessionlog)
* [`nopresent`](#nopresent)
* [`reloadhint`](#reloadhint)
* [`sync_size_soft_limit`](#sync_size_soft_limit)
* [`sync_size_hard_limit`](#sync_size_hard_limit)
* [`sync_time_soft_limit`](#sync_time_soft_limit)
* [`sync_time_hard_limit`](#sync_time_hard_limit)

##### <a name="checkpoint"></a>`checkpoint`

Data type: `Optional[Pattern['^\d+\s\d+$']]`



Default value: ``undef``

##### <a name="sessionlog"></a>`sessionlog`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="nopresent"></a>`nopresent`

Data type: `Boolean`



Default value: ``false``

##### <a name="reloadhint"></a>`reloadhint`

Data type: `Boolean`



Default value: ``false``

##### <a name="sync_size_soft_limit"></a>`sync_size_soft_limit`

Data type: `Variant[Enum['unlimited'], Integer]`



Default value: `'unlimited'`

##### <a name="sync_size_hard_limit"></a>`sync_size_hard_limit`

Data type: `Variant[Enum['unlimited'], Integer]`



Default value: `'unlimited'`

##### <a name="sync_time_soft_limit"></a>`sync_time_soft_limit`

Data type: `Variant[Enum['unlimited'], Integer]`



Default value: `'unlimited'`

##### <a name="sync_time_hard_limit"></a>`sync_time_hard_limit`

Data type: `Variant[Enum['unlimited'], Integer]`



Default value: `'unlimited'`

## Defined types

### <a name="simp_openldapserveraccess"></a>`simp_openldap::server::access`

Remember that **order matters**! Entries will be listed in alphanumeric order
after the ``$order`` parameter is processed.

* **See also**
  * slapd.access(5)

#### Parameters

The following parameters are available in the `simp_openldap::server::access` defined type:

* [`name`](#name)
* [`what`](#what)
* [`comment`](#comment)
* [`who`](#who)
* [`access`](#access)
* [`control`](#control)
* [`content`](#content)
* [`order`](#order)

##### <a name="name"></a>`name`

The unique name of the dynamic include. This does become part of the sort
order so be careful!

##### <a name="what"></a>`what`

Data type: `String`

The entity this access control directive applies to.

##### <a name="comment"></a>`comment`

Data type: `Optional[String]`

An arbitrary comment that will be included above the entry

* You do not need to include the leading `#`

Default value: ``undef``

##### <a name="who"></a>`who`

Data type: `Optional[String]`

Whom this access rule applies to.

Default value: ``undef``

##### <a name="access"></a>`access`

Data type: `Optional[String]`

The access level or the specific access privileges the ``who`` field will have

Default value: ``undef``

##### <a name="control"></a>`control`

Data type: `Optional[String]`

The control of the flow of access rule application to be applied

Default value: ``undef``

##### <a name="content"></a>`content`

Data type: `Optional[String]`

the **entire* content under ``$what``

* If you do not specify this, ``$who`` is a required variable
* If you do specify this, ``$who`` will be ignored

Default value: ``undef``

##### <a name="order"></a>`order`

Data type: `Integer`

The default sort order of the entry to be added

Default value: `1000`

### <a name="simp_openldapserverdynamic_include"></a>`simp_openldap::server::dynamic_include`

Add a dynamically included file into the LDAP system.

#### Parameters

The following parameters are available in the `simp_openldap::server::dynamic_include` defined type:

* [`content`](#content)
* [`order`](#order)

##### <a name="content"></a>`content`

Data type: `String`

The literal content of the dynamic include

##### <a name="order"></a>`order`

Data type: `Integer`

The numeric order of the dynamic include

Default value: `100`

### <a name="simp_openldapserverlimits"></a>`simp_openldap::server::limits`

Manage ``limits`` sections under the **main** database

* **See also**
  * slapd.conf(5)

#### Parameters

The following parameters are available in the `simp_openldap::server::limits` defined type:

* [`name`](#name)
* [`who`](#who)
* [`limits`](#limits)

##### <a name="name"></a>`name`

A unique name for the limits entry

##### <a name="who"></a>`who`

Data type: `String`

Any of the following values (not validated)
  * ``*``                          All, including anonymous and authenticated users
  * ``anonymous``                  Anonymous (non-authenticated) users
  * ``users``                      Authenticated users
  * ``self``                       User associated with target entry
  * ``dn[.<basic-style>]=<regex>`` Users matching a regular expression
  * ``dn.<scope-style>=<DN>``      Users within scope of a DN
  * ``group[/oc[/at]]=<pattern>``  Members of a group

##### <a name="limits"></a>`limits`

Data type: `Variant[Array[String],String]`

A list of limits to apply to ``$who`` per ``slapd.conf(5)``

### <a name="simp_openldapserversyncrepl"></a>`simp_openldap::server::syncrepl`

for directory synchronization pulls from a master server.

$name should be the 'rid' of the syncrepl instance and must be between 0 and
1000, non-inclusive.

* **See also**
  * slapd.conf(5)

#### Parameters

The following parameters are available in the `simp_openldap::server::syncrepl` defined type:

* [`syncrepl_retry`](#syncrepl_retry)
* [`provider`](#provider)
* [`searchbase`](#searchbase)
* [`syncrepl_type`](#syncrepl_type)
* [`interval`](#interval)
* [`filter`](#filter)
* [`syncrepl_scope`](#syncrepl_scope)
* [`attrs`](#attrs)
* [`attrsonly`](#attrsonly)
* [`sizelimit`](#sizelimit)
* [`timelimit`](#timelimit)
* [`schemachecking`](#schemachecking)
* [`starttls`](#starttls)
* [`bindmethod`](#bindmethod)
* [`binddn`](#binddn)
* [`saslmech`](#saslmech)
* [`authcid`](#authcid)
* [`authzid`](#authzid)
* [`credentials`](#credentials)
* [`realm`](#realm)
* [`secprops`](#secprops)
* [`logbase`](#logbase)
* [`logfilter`](#logfilter)
* [`syncdata`](#syncdata)
* [`updateref`](#updateref)

##### <a name="syncrepl_retry"></a>`syncrepl_retry`

Data type: `String[1]`



Default value: `'60 10 600 +'`

##### <a name="provider"></a>`provider`

Data type: `Optional[String[1]]`



Default value: `simplib::lookup('simp_options::ldap::master', { 'default_value'  => undef })`

##### <a name="searchbase"></a>`searchbase`

Data type: `Optional[String[1]]`



Default value: `simplib::lookup('simp_options::ldap::base_dn', { 'default_value' => undef })`

##### <a name="syncrepl_type"></a>`syncrepl_type`

Data type: `Enum['refreshOnly','refreshAndPersist']`



Default value: `'refreshAndPersist'`

##### <a name="interval"></a>`interval`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="filter"></a>`filter`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="syncrepl_scope"></a>`syncrepl_scope`

Data type: `String[1]`



Default value: `'sub'`

##### <a name="attrs"></a>`attrs`

Data type: `String[1]`



Default value: `'*,+'`

##### <a name="attrsonly"></a>`attrsonly`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="sizelimit"></a>`sizelimit`

Data type: `Variant[Enum['unlimited'], Integer[0]]`



Default value: `'unlimited'`

##### <a name="timelimit"></a>`timelimit`

Data type: `Variant[Enum['unlimited'], Integer[0]]`



Default value: `'unlimited'`

##### <a name="schemachecking"></a>`schemachecking`

Data type: `Enum['on','off']`



Default value: `'off'`

##### <a name="starttls"></a>`starttls`

Data type: `Variant[Enum['critical'], Boolean]`



Default value: `'critical'`

##### <a name="bindmethod"></a>`bindmethod`

Data type: `Enum['simple','sasl']`



Default value: `'simple'`

##### <a name="binddn"></a>`binddn`

Data type: `Optional[String[1]]`



Default value: `simplib::lookup('simp_options::ldap::sync_dn', {'default_value'  => undef })`

##### <a name="saslmech"></a>`saslmech`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="authcid"></a>`authcid`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="authzid"></a>`authzid`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="credentials"></a>`credentials`

Data type: `Optional[String[1]]`



Default value: `simplib::lookup('simp_options::ldap::sync_pw', { 'default_value' => undef })`

##### <a name="realm"></a>`realm`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="secprops"></a>`secprops`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="logbase"></a>`logbase`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="logfilter"></a>`logfilter`

Data type: `Optional[String[1]]`



Default value: ``undef``

##### <a name="syncdata"></a>`syncdata`

Data type: `Enum['default','accesslog']`



Default value: `'default'`

##### <a name="updateref"></a>`updateref`

Data type: `Optional[String[1]]`



Default value: ``undef``

## Data types

### <a name="simp_openldaploglevel"></a>`Simp_Openldap::LogLevel`

OpenLDAP Log Levels

Alias of

```puppet
Variant[Integer[-1,65535], Enum[
  'any',
  '-',
  'trace',
  'packets',
  'args',
  'conns',
  'BER',
  'ber',
  'filter',
  'config',
  'ACL',
  'acl',
  'stats',
  'stats2',
  'shell',
  'parse',
  'cache',
  'index',
  'sync',
  'none'
]]
```

### <a name="simp_openldapslapdconfdisallow"></a>`Simp_Openldap::SlapdConf::Disallow`

OpenLDAP slapd.conf disallow

Alias of

```puppet
Enum['bind_anon', 'bind_simple', 'tls_2_anon', 'tls_authc', 'proxy_authz_non_critical', 'dontusecopy_non_critical']
```

